Function breadcrumb
pub fn breadcrumb() -> ChatMessageExpand description
Front breadcrumb injected after the system messages so the model SEES that earlier turns were cut and cannot confabulate dropped work as present.
pub fn breadcrumb() -> ChatMessageFront breadcrumb injected after the system messages so the model SEES that earlier turns were cut and cannot confabulate dropped work as present.