Struct CalendarNoShowEvent
pub struct CalendarNoShowEvent {
pub event_id: String,
pub event_title: String,
pub expected_start: DateTime<Utc>,
pub detected_at: DateTime<Utc>,
pub calendar_source: String,
pub calendar_id: String,
}Expand description
Emitted when a tracked calendar event reaches its no-show threshold.
Fields
event_id: Stringevent_title: Stringexpected_start: DateTime<Utc>detected_at: DateTime<Utc>calendar_source: Stringcalendar_id: StringTrait Implementations
Sourceimpl Clone for CalendarNoShowEvent
impl Clone for CalendarNoShowEvent
Sourcefn clone(&self) -> CalendarNoShowEvent
fn clone(&self) -> CalendarNoShowEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CalendarNoShowEvent
impl Debug for CalendarNoShowEvent
Sourceimpl<'de> Deserialize<'de> for CalendarNoShowEvent
impl<'de> Deserialize<'de> for CalendarNoShowEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for CalendarNoShowEvent
impl PartialEq for CalendarNoShowEvent
Sourcefn eq(&self, other: &CalendarNoShowEvent) -> bool
fn eq(&self, other: &CalendarNoShowEvent) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for CalendarNoShowEvent
impl Serialize for CalendarNoShowEvent
impl Eq for CalendarNoShowEvent
impl StructuralPartialEq for CalendarNoShowEvent