pub struct DaemonRegistry { /* private fields */ }Expand description
Typed startup registry injected by the binary crate.
This registry is the source of truth for startup hook values for the current
daemon run/reload iteration. It deliberately does not copy config-derived
facts; Config remains the source of truth for which subsystems are enabled.
Implementations
Sourceimpl DaemonRegistry
impl DaemonRegistry
Sourcepub fn new() -> Self
pub fn new() -> Self
Create an empty registry. Missing starters are treated as unwired
optional subsystems by daemon::run.
pub fn register_gateway( &mut self, starter: Box<dyn Fn(String, u16, Config, Option<Sender<Value>>, Option<Sender<bool>>, Option<Arc<TuiRegistry>>) -> Pin<Box<dyn Future<Output = Result<()>> + Send>> + Send + Sync>, ) -> &mut Self
pub fn register_channels( &mut self, starter: Box<dyn Fn(Config, CancellationToken) -> Pin<Box<dyn Future<Output = Result<()>> + Send>> + Send + Sync>, ) -> &mut Self
pub fn register_socket( &mut self, starter: Box<dyn Fn(Arc<RpcContext>, CancellationToken, Arc<AtomicUsize>) -> Pin<Box<dyn Future<Output = Result<()>> + Send>> + Send + Sync>, ) -> &mut Self
pub fn register_wss( &mut self, starter: Box<dyn Fn(Arc<RpcContext>, CancellationToken, Arc<AtomicUsize>) -> Pin<Box<dyn Future<Output = Result<()>> + Send>> + Send + Sync>, ) -> &mut Self
pub fn register_mqtt( &mut self, starter: Box<dyn Fn(MqttConfig) -> Pin<Box<dyn Future<Output = Result<()>> + Send>> + Send + Sync>, ) -> &mut Self