Function run_structured
pub async fn run_structured(config: &Config) -> Vec<DiagResult>Expand description
Run the full Doctor suite and return the structured result used by CLI and RPC.
pub async fn run_structured(config: &Config) -> Vec<DiagResult>Run the full Doctor suite and return the structured result used by CLI and RPC.