Function shutdown_notify
pub fn shutdown_notify() -> &'static NotifyExpand description
The global in-process shutdown trigger, for the daemon loop to await.
pub fn shutdown_notify() -> &'static NotifyThe global in-process shutdown trigger, for the daemon loop to await.