Function validate_uniqueness
pub fn validate_uniqueness(
config: &Config,
install_root: &Path,
) -> Result<(), BundleDirectoryError>Expand description
Reject configs where two bundles resolve to the same directory.
pub fn validate_uniqueness(
config: &Config,
install_root: &Path,
) -> Result<(), BundleDirectoryError>Reject configs where two bundles resolve to the same directory.