Struct SlashOptionKindDescriptor
pub struct SlashOptionKindDescriptor {
pub manifest_name: String,
pub supports_choices: bool,
pub supports_numeric_bounds: bool,
pub supports_length_bounds: bool,
}Expand description
Serialized capability row for one SlashOptionKind, as published to
surfaces (the web dashboard mirrors this shape). Built by walking
SlashOptionKind::ALL; never hand-authored.
Fields
manifest_name: Stringsupports_choices: boolsupports_numeric_bounds: boolsupports_length_bounds: boolTrait Implementations
Sourceimpl Clone for SlashOptionKindDescriptor
impl Clone for SlashOptionKindDescriptor
Sourcefn clone(&self) -> SlashOptionKindDescriptor
fn clone(&self) -> SlashOptionKindDescriptor
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SlashOptionKindDescriptor
impl Debug for SlashOptionKindDescriptor
Sourceimpl JsonSchema for SlashOptionKindDescriptor
impl JsonSchema for SlashOptionKindDescriptor
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SlashOptionKindDescriptor
impl PartialEq for SlashOptionKindDescriptor
Sourcefn eq(&self, other: &SlashOptionKindDescriptor) -> bool
fn eq(&self, other: &SlashOptionKindDescriptor) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SlashOptionKindDescriptor