Function test_skill
pub fn test_skill(
skill_dir: &Path,
skill_name: &str,
verbose: bool,
) -> Result<SkillTestResult>Expand description
Test a single skill by parsing and running its TEST.sh.
pub fn test_skill(
skill_dir: &Path,
skill_name: &str,
verbose: bool,
) -> Result<SkillTestResult>Test a single skill by parsing and running its TEST.sh.