Enum ApprovalRouteIssue
pub enum ApprovalRouteIssue {
Malformed {
policy: String,
route_kind: &'static str,
route: String,
},
UndeliverableChannel {
policy: String,
route_kind: &'static str,
route: String,
channel_key: String,
},
}Expand description
A route configuration problem reported at daemon startup before a parked gate would otherwise discover it during delivery.
Variants