Struct ConditionOpSpec
pub struct ConditionOpSpec {
pub token: String,
pub label: String,
}Expand description
Wire shape of one operator for authoring surfaces: the literal token to
splice into a condition string, and a human label to show in a picker.
Fields
token: Stringlabel: StringTrait Implementations
Sourceimpl Clone for ConditionOpSpec
impl Clone for ConditionOpSpec
Sourcefn clone(&self) -> ConditionOpSpec
fn clone(&self) -> ConditionOpSpec
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConditionOpSpec
impl Debug for ConditionOpSpec
Sourceimpl<'de> Deserialize<'de> for ConditionOpSpec
impl<'de> Deserialize<'de> for ConditionOpSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ConditionOpSpec
impl JsonSchema for ConditionOpSpec
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ConditionOpSpec
impl PartialEq for ConditionOpSpec
Sourceimpl Serialize for ConditionOpSpec
impl Serialize for ConditionOpSpec
impl Eq for ConditionOpSpec
impl StructuralPartialEq for ConditionOpSpec