Struct GraphLayout
pub struct GraphLayout {
pub positions: Vec<NodePosition>,
pub columns: u32,
pub rows: u32,
pub geometry: LayoutGeometry,
}Expand description
Deterministic auto-layout so every surface renders the same picture without a client-side layout engine.
Fields
positions: Vec<NodePosition>columns: u32rows: u32geometry: LayoutGeometryTrait Implementations
Sourceimpl Clone for GraphLayout
impl Clone for GraphLayout
Sourcefn clone(&self) -> GraphLayout
fn clone(&self) -> GraphLayout
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GraphLayout
impl Debug for GraphLayout
Sourceimpl Default for GraphLayout
impl Default for GraphLayout
Sourcefn default() -> GraphLayout
fn default() -> GraphLayout
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for GraphLayout
impl<'de> Deserialize<'de> for GraphLayout
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<GraphLayout, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<GraphLayout, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for GraphLayout
impl JsonSchema for GraphLayout
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for GraphLayout
impl PartialEq for GraphLayout
Sourceimpl Serialize for GraphLayout
impl Serialize for GraphLayout
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for GraphLayout