Struct StepPos
pub struct StepPos {
pub x: f64,
pub y: f64,
}Expand description
Persisted canvas coordinate for a step node. Written by the Blueprint editor when a node is dragged; never edited in the step-definition form.
Fields
x: f64y: f64Trait Implementations
Sourceimpl<'de> Deserialize<'de> for StepPos
impl<'de> Deserialize<'de> for StepPos
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StepPos
impl JsonSchema for StepPos
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl Copy for StepPos
impl StructuralPartialEq for StepPos