Enum WireOp
pub enum WireOp {
Connect,
Disconnect,
}Variants
Connect
Create the edge, overwriting any previous target of the same role.
Disconnect
Remove the edge only if it currently points at the given target.