Struct ReactionTool
pub struct ReactionTool { /* private fields */ }Expand description
Agent-callable tool for adding or removing emoji reactions on messages.
Implementations
Sourceimpl ReactionTool
impl ReactionTool
Sourcepub fn new(
security: Arc<SecurityPolicy>,
channels: Arc<RwLock<RawRwLock, HashMap<String, Arc<dyn Channel>>>>,
) -> ReactionTool
pub fn new( security: Arc<SecurityPolicy>, channels: Arc<RwLock<RawRwLock, HashMap<String, Arc<dyn Channel>>>>, ) -> ReactionTool
Create a new reaction tool using the given channel map.