Function stderr_is_interactive_foreground
pub fn stderr_is_interactive_foreground() -> boolExpand description
Return whether stderr is an interactive terminal currently owned by this process group. Job-control ownership can change while the daemon is running.