Function resolve_model_provider_type
pub fn resolve_model_provider_type(
type_key: &str,
) -> Option<(&'static str, bool)>Expand description
Resolve a Quickstart provider-type input to the canonical config family.
The provider registry remains the source of truth for real config families.
Auth-provider aliases (openai-codex, claude, google, grok, …)
are accepted as Quickstart conveniences and normalize to existing config
families. Only openai-codex preselects a different Quickstart auth mode.