Function request_respawn
pub fn request_respawn()Expand description
Request a self-respawn after the daemon shuts down. The caller is expected to also trigger the daemon’s graceful shutdown so the loop tears down first.
pub fn request_respawn()Request a self-respawn after the daemon shuts down. The caller is expected to also trigger the daemon’s graceful shutdown so the loop tears down first.